# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from .knowledge_base_response import KnowledgeBaseResponse

__all__ = ["KnowledgeBaseListResponse"]

KnowledgeBaseListResponse: TypeAlias = List[KnowledgeBaseResponse]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import TypedDict

__all__ = ["PhoneNumberCreateParams"]


class PhoneNumberCreateParams(TypedDict, total=False):
    area_code: int
    """Area code of the number to obtain.

    Format is a 3 digit integer. Currently only supports US area code.
    """

    inbound_agent_id: Optional[str]
    """Unique id of agent to bind to the number.

    The number will automatically use the agent when receiving inbound calls. If
    null, this number would not accept inbound call.
    """

    nickname: str
    """Nickname of the number. This is for your reference only."""

    outbound_agent_id: Optional[str]
    """Unique id of agent to bind to the number.

    The number will automatically use the agent when conducting outbound calls. If
    null, this number would not be able to initiate outbound call without agent id
    override.
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .llm_response import LlmResponse as LlmResponse
from .call_response import CallResponse as CallResponse
from .agent_response import AgentResponse as AgentResponse
from .voice_response import VoiceResponse as VoiceResponse
from .call_list_params import CallListParams as CallListParams
from .llm_create_params import LlmCreateParams as LlmCreateParams
from .llm_list_response import LlmListResponse as LlmListResponse
from .llm_update_params import LlmUpdateParams as LlmUpdateParams
from .web_call_response import WebCallResponse as WebCallResponse
from .call_list_response import CallListResponse as CallListResponse
from .agent_create_params import AgentCreateParams as AgentCreateParams
from .agent_list_response import AgentListResponse as AgentListResponse
from .agent_update_params import AgentUpdateParams as AgentUpdateParams
from .phone_call_response import PhoneCallResponse as PhoneCallResponse
from .voice_list_response import VoiceListResponse as VoiceListResponse
from .phone_number_response import PhoneNumberResponse as PhoneNumberResponse
from .knowledge_base_response import KnowledgeBaseResponse as KnowledgeBaseResponse
from .phone_number_create_params import PhoneNumberCreateParams as PhoneNumberCreateParams
from .phone_number_import_params import PhoneNumberImportParams as PhoneNumberImportParams
from .phone_number_list_response import PhoneNumberListResponse as PhoneNumberListResponse
from .phone_number_update_params import PhoneNumberUpdateParams as PhoneNumberUpdateParams
from .call_create_web_call_params import CallCreateWebCallParams as CallCreateWebCallParams
from .knowledge_base_create_params import KnowledgeBaseCreateParams as KnowledgeBaseCreateParams
from .knowledge_base_list_response import KnowledgeBaseListResponse as KnowledgeBaseListResponse
from .call_create_phone_call_params import CallCreatePhoneCallParams as CallCreatePhoneCallParams
from .concurrency_retrieve_response import ConcurrencyRetrieveResponse as ConcurrencyRetrieveResponse
from .call_register_phone_call_params import CallRegisterPhoneCallParams as CallRegisterPhoneCallParams
from .knowledge_base_add_sources_params import KnowledgeBaseAddSourcesParams as KnowledgeBaseAddSourcesParams



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .llm import (
    LlmResource,
    AsyncLlmResource,
    LlmResourceWithRawResponse,
    AsyncLlmResourceWithRawResponse,
    LlmResourceWithStreamingResponse,
    AsyncLlmResourceWithStreamingResponse,
)
from .call import (
    CallResource,
    AsyncCallResource,
    CallResourceWithRawResponse,
    AsyncCallResourceWithRawResponse,
    CallResourceWithStreamingResponse,
    AsyncCallResourceWithStreamingResponse,
)
from .agent import (
    AgentResource,
    AsyncAgentResource,
    AgentResourceWithRawResponse,
    AsyncAgentResourceWithRawResponse,
    AgentResourceWithStreamingResponse,
    AsyncAgentResourceWithStreamingResponse,
)
from .voice import (
    VoiceResource,
    AsyncVoiceResource,
    VoiceResourceWithRawResponse,
    AsyncVoiceResourceWithRawResponse,
    VoiceResourceWithStreamingResponse,
    AsyncVoiceResourceWithStreamingResponse,
)
from .concurrency import (
    ConcurrencyResource,
    AsyncConcurrencyResource,
    ConcurrencyResourceWithRawResponse,
    AsyncConcurrencyResourceWithRawResponse,
    ConcurrencyResourceWithStreamingResponse,
    AsyncConcurrencyResourceWithStreamingResponse,
)
from .phone_number import (
    PhoneNumberResource,
    AsyncPhoneNumberResource,
    PhoneNumberResourceWithRawResponse,
    AsyncPhoneNumberResourceWithRawResponse,
    PhoneNumberResourceWithStreamingResponse,
    AsyncPhoneNumberResourceWithStreamingResponse,
)
from .knowledge_base import (
    KnowledgeBaseResource,
    AsyncKnowledgeBaseResource,
    KnowledgeBaseResourceWithRawResponse,
    AsyncKnowledgeBaseResourceWithRawResponse,
    KnowledgeBaseResourceWithStreamingResponse,
    AsyncKnowledgeBaseResourceWithStreamingResponse,
)

__all__ = [
    "CallResource",
    "AsyncCallResource",
    "CallResourceWithRawResponse",
    "AsyncCallResourceWithRawResponse",
    "CallResourceWithStreamingResponse",
    "AsyncCallResourceWithStreamingResponse",
    "PhoneNumberResource",
    "AsyncPhoneNumberResource",
    "PhoneNumberResourceWithRawResponse",
    "AsyncPhoneNumberResourceWithRawResponse",
    "PhoneNumberResourceWithStreamingResponse",
    "AsyncPhoneNumberResourceWithStreamingResponse",
    "AgentResource",
    "AsyncAgentResource",
    "AgentResourceWithRawResponse",
    "AsyncAgentResourceWithRawResponse",
    "AgentResourceWithStreamingResponse",
    "AsyncAgentResourceWithStreamingResponse",
    "LlmResource",
    "AsyncLlmResource",
    "LlmResourceWithRawResponse",
    "AsyncLlmResourceWithRawResponse",
    "LlmResourceWithStreamingResponse",
    "AsyncLlmResourceWithStreamingResponse",
    "KnowledgeBaseResource",
    "AsyncKnowledgeBaseResource",
    "KnowledgeBaseResourceWithRawResponse",
    "AsyncKnowledgeBaseResourceWithRawResponse",
    "KnowledgeBaseResourceWithStreamingResponse",
    "AsyncKnowledgeBaseResourceWithStreamingResponse",
    "VoiceResource",
    "AsyncVoiceResource",
    "VoiceResourceWithRawResponse",
    "AsyncVoiceResourceWithRawResponse",
    "VoiceResourceWithStreamingResponse",
    "AsyncVoiceResourceWithStreamingResponse",
    "ConcurrencyResource",
    "AsyncConcurrencyResource",
    "ConcurrencyResourceWithRawResponse",
    "AsyncConcurrencyResourceWithRawResponse",
    "ConcurrencyResourceWithStreamingResponse",
    "AsyncConcurrencyResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .._models import BaseModel

__all__ = ["PhoneNumberResponse"]


class PhoneNumberResponse(BaseModel):
    last_modification_timestamp: int
    """Last modification timestamp (milliseconds since epoch).

    Either the time of last update or creation if no updates available.
    """

    phone_number: str
    """
    E.164 format of the number (+country code, then number with no space, no special
    characters), used as the unique identifier for phone number APIs.
    """

    area_code: Optional[int] = None
    """Area code of the number to obtain.

    Format is a 3 digit integer. Currently only supports US area code.
    """

    inbound_agent_id: Optional[str] = None
    """Unique id of agent to bind to the number.

    The number will automatically use the agent when receiving inbound calls. If
    null, this number would not accept inbound call.
    """

    nickname: Optional[str] = None
    """Nickname of the number. This is for your reference only."""

    outbound_agent_id: Optional[str] = None
    """Unique id of agent to bind to the number.

    The number will automatically use the agent when conducting outbound calls. If
    null, this number would not be able to initiate outbound call without agent id
    override.
    """

    phone_number_pretty: Optional[str] = None
    """Pretty printed phone number, provided for your reference."""
